"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./../../../shared/constants");
let fs = require("fs");
const logger_1 = __importDefault(require("./../../../shared/logger"));
const sonar_template_1 = require("./util/sonar-template");
const { configDir, sonarDir } = constants_1.consts.aws_template;
const dirname = process.cwd() + `/${configDir}`;
const chalk_1 = __importDefault(require("chalk"));
exports.default = (repository, version, src) => __awaiter(void 0, void 0, void 0, function* () {
    logger_1.default.info(`Creating the sonar file`);
    try {
        yield ensureDirectoryExistence(dirname);
        yield ensureDirectoryExistence(dirname + `/${sonarDir}`);
        logger_1.default.info(`${chalk_1.default.redBright("name")} ${repository} ${chalk_1.default.redBright("version")} ${version} ${chalk_1.default.redBright("directory")} ${src}`);
        yield fs.writeFileSync(`${dirname}/${sonarDir}/sonar-project.properties`, yield sonar_template_1.sonarTemplate(repository, version, src), function (err) {
            if (err) {
                throw err;
            }
        });
        logger_1.default.info("Sonar file created succesfully.");
    }
    catch (error) {
        logger_1.default.debug("error" + error);
    }
});
const ensureDirectoryExistence = (filePath) => __awaiter(void 0, void 0, void 0, function* () {
    if (fs.existsSync(filePath)) {
        return true;
    }
    yield fs.mkdirSync(filePath);
    return true;
});
