"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const logger_1 = __importDefault(require("./../../../shared/logger"));
const get_content_files_1 = require("../../../shared/util/get-content-files");
const fs_1 = __importDefault(require("fs"));
const run_multiple_command_1 = require("../../../shared/util/run-multiple-command");
const directory = process.cwd() + '/';
let commandAdminPackage = '';
exports.default = (adminPackage) => __awaiter(void 0, void 0, void 0, function* () {
    logger_1.default.info('Install dependencies');
    commandAdminPackage = adminPackage;
    //1. Busco en el directorio actual si existen proyectos con el archivo manifest.json
    let response = yield findProject([directory]);
    // si no se encontraron projectos en el directorio actual, paso a buscar en los sub directorios.
    if (!response) {
        // obtengo todos los nombres de las carpetas dentro del directorio indicado
        let files = yield get_content_files_1.getDirectories(directory);
        if (files.length) {
            let subFiles = yield findProject(files);
            if (!subFiles) {
                process.exit(1);
            }
            else {
                logger_1.default.info(`Proyect found in the sub location`);
            }
        }
        else {
            logger_1.default.warn(`No projects found in ${directory}`);
            process.exit(1);
        }
    }
});
//2. Tomo el directorio encontrado y paso a buscar la carpeta node o react
const findProject = (files) => __awaiter(void 0, void 0, void 0, function* () {
    // si hay directorios, paso a buscar el archivo manifest.json y obtener su contenido
    logger_1.default.debug(`Searchin proyect in ${files}`);
    const manifests = yield get_content_files_1.getManifestsContent(files);
    if (manifests.length) {
        logger_1.default.info(`Proyect found in the folder: ${files}`);
        manifests.map((item) => {
            findNodeOrReactFolder(item.path);
        });
        return true;
    }
    else {
        return false;
    }
});
//3. De acuerdo al directorio encontrado, paso a realizar la instalación de las dependencias
const findNodeOrReactFolder = (file) => __awaiter(void 0, void 0, void 0, function* () {
    if (fs_1.default.existsSync(file + '/node') == true) {
        logger_1.default.info('Proyect contain the folder node');
        const command = `cd ${file}/node && ${commandAdminPackage} && cd ../..`;
        run_multiple_command_1.runMultipleCommand(command);
    }
    else if (fs_1.default.existsSync(file + '/react') == true) {
        logger_1.default.info('Proyect contain the folder react');
        const command = `cd ${file}/react && ${commandAdminPackage} && cd ../..`;
        run_multiple_command_1.runMultipleCommand(command);
    }
});
